informativeNoisePrior returns an informative noise prior for GFA, for
a given data collection. The function sets the noise residual parameters
such that the expected proportion of
variance explained is for all variables and groups (in contrast to being
proportional to their original scale). Recommended e.g. when the data is
'small n, large p', and the standard prior from getDefaultOpts
seems to overfit the model by not shutting off any component with high
initial K.
The input model options (opts) with an updated residual
noise prior, corresponding to the elements prior.alpha_0t and
prior.beta_0t.
Arguments
Y
The data. For details, see function gfa.
opts
Model options. See function getDefaultOpts for
details. If option tauGrouped is TRUE (default), each data source is given
equal importance (feature importance may vary within each
source). If it is FALSE, each feature is given equal importance.
noiseProportion
proportion of total variance to be
explained by noise. Suggested to lie between 0.01 and 0.99.
conf
Confidence in the prior, relative to confidence in the data.
Suggested to lie between 0.01 and 100.