reconstruction returns the full data reconstruction based on given
posterior samples.
reconstruction(res, average = TRUE)The data reconstruction, a numeric \(N \times \sum_{m=1}^M D_m\)
matrix, if average is TRUE (default). Otherwise, the reconstruction is a
\(N \times \sum_{m=1}^M D_m \times Npost\) array, with posterior samples in the third dimension. If the input data has been paired in two modes, the output will be a list of length 2, one element corresponding to each mode.
The sampled model from function gfa
If TRUE (default), averages the reconstruction over the posterior predictive samples. If set to FALSE, the output may require a large amount of memory. In case of large input data, we recommend acquiring the posterior predictive samples for subsets of data at a time, based on this implementation.